From da6edbdcf778d24e0718b90afad23a007d5525cb Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Felix=20Paul=20Ku=CC=88hne?= <fkuehne@videolan.org>
Date: Sat, 25 Aug 2012 00:22:20 +0200
Subject: [PATCH] auhal: implemented MuteSet

---
 modules/audio_output/auhal.c |   27 ++++++++++++++++++++++++++-
 1 file changed, 26 insertions(+), 1 deletion(-)

diff --git a/modules/audio_output/auhal.c b/modules/audio_output/auhal.c
index f2b0918..dfb8a72 100644
--- a/modules/audio_output/auhal.c
+++ b/modules/audio_output/auhal.c
@@ -85,6 +85,7 @@ struct aout_sys_t
     uint8_t                     p_remainder_buffer[BUFSIZE];
     uint32_t                    i_read_bytes;
     uint32_t                    i_total_bytes;
+    float                       f_last_known_volume;
 
     /* CoreAudio SPDIF mode specific */
     pid_t                       i_hog_pid;           /* The keep the pid of our hog status */
@@ -1480,7 +1481,31 @@ static int VolumeSet( audio_output_t * p_aout, float volume )
 
 static int MuteSet( audio_output_t * p_aout, bool mute )
 {
+    /* CoreAudio/AUHAL can only mute entire devices, but no individual units, so
+     * we need to fake the requested behavior */
+    struct   aout_sys_t *p_sys = p_aout->sys;
+    OSStatus ostatus;
+    float volume;
+
+    if (mute) {
+        ostatus = AudioUnitGetParameter( p_sys->au_unit,
+                                        kHALOutputParam_Volume,
+                                        kAudioUnitScope_Global,
+                                        0,
+                                        &p_sys->f_last_known_volume);
+        volume = .0;
+    } else
+        volume = p_sys->f_last_known_volume;
+
+    /* Set volume for output unit */
+    ostatus = AudioUnitSetParameter( p_sys->au_unit,
+                                    kHALOutputParam_Volume,
+                                    kAudioUnitScope_Global,
+                                    0,
+                                    volume,
+                                    0 );
+
     aout_MuteReport( p_aout, mute );
 
-    return 0;
+    return ostatus;
 }
-- 
1.7.10.2 (Apple Git-33)

